@@ -1,5 +1,8 @@
+from pedal.core.feedback import Feedback
+from pedal.core.feedback_category import FeedbackCategory, FeedbackKind
 from pedal.core.report import MAIN_REPORT
 from pedal.questions.graders import QuestionGrader
+from pedal.questions.constants import TOOL_NAME
 
 
 class Question:
@@ -30,15 +33,23 @@ class Question:
             for test in self.tests:
                 test(self)
         if not self.answered:
-            show_question(self.instructions, self.report)
+            show_question(self.instructions, report=self.report)
 
 
-def show_question(instructions, report=MAIN_REPORT):
+class show_question(Feedback):
     """
 
     Args:
         instructions:
         report:
     """
-    report.attach('Question', category='Instructions', tool='Questions',
-                  group=report.group, priority='instructions', hint=instructions)
+    category = FeedbackCategory.INSTRUCTIONS
+    kind = FeedbackKind.INSTRUCTIONAL
+    justification = 'Question was asked but not answered.'
+    title = 'Show Question'
+    priority = 'instructions'
+    tool = TOOL_NAME
+    valence = 0
+
+    def __init__(self, instructions, **kwargs):
+        super().__init__(message=instructions, **kwargs)
