@@ -1,26 +1,41 @@
-from pedal.core.report import MAIN_REPORT
+"""
+Initialize and setup the Questions tool.
+"""
+
+from pedal.core.report import MAIN_REPORT, Report
+from pedal.questions.constants import TOOL_NAME
 
 import hashlib
 
-def _name_hash(name):
+
+def _name_hash(name: str) -> int:
+    """ Turn a string name into a unique hashcode using MD5 """
     return hashlib.md5(name.encode('utf8')).digest()[0]
 
-def _setup_questions(report):
-    '''
-    Initialize any necessary fields for the report's question tool.
-    
+
+def reset(report=MAIN_REPORT):
+    """
+    Remove all settings for the Questions tool. Seed will be 0.
+
     Args:
-        report (Report): The report object to store data and feedback in.
-    '''
-    if 'questions' not in report:
-        report['questions'] = {
-            'seed': 0
-        }
+        report: The report object
+
+    Returns:
+        This tool's data
+    """
+    report[TOOL_NAME] = {
+        'seed': 0
+    }
+    return report[TOOL_NAME]
+
+
+Report.register_tool(TOOL_NAME, reset)
+
 
 def set_seed(seed_value, report=MAIN_REPORT):
-    '''
+    """
     Sets the seed that will be used in selecting questions.
-    
+
     Args:
         seed_value (int or str or iterable[int]): The value to use when
             selecting questions, deterministically. If int, the same index
@@ -33,5 +48,5 @@ def set_seed(seed_value, report=MAIN_REPORT):
             need to limit your questions to 256.
         report (Report): The report object to store data and feedback in. If
             left None, defaults to the global MAIN_REPORT.
-    '''
+    """
     report['questions']['seed'] = seed_value
